Types
=====

Lifetime
--------

.. autoclass:: diwire.Lifetime
   :members:

LockMode
--------

.. autoclass:: diwire.LockMode
   :members:

ResolverProtocol
----------------

.. autoclass:: diwire.ResolverProtocol
   :members:

Scope
-----

.. autoclass:: diwire.BaseScope

.. autodata:: diwire.Scope

Injected
--------

.. autoclass:: diwire.Injected

Component
---------

.. autoclass:: diwire.Component

All
---

.. autoclass:: diwire.All

Maybe
-----

.. autoclass:: diwire.Maybe

Provider
--------

.. autoclass:: diwire.Provider

AsyncProvider
-------------

.. autoclass:: diwire.AsyncProvider
